.. ui.cmdline.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive._ui._cmdline package.



AutoArchive._ui._cmdline
========================

.. automodule:: AutoArchive._ui._cmdline
   :no-members:



Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   ui.cmdline.core



Modules
-------

cmdline_commands
^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._ui._cmdline.cmdline_commands
